@@ -327,7 +327,7 @@ class Gateway():
 
     async def gatewayReady(self):
         state = await self.gatewayState() 
-        if state == "READY":
+        if state == ServiceState.READY:
             return
         else:
             raise GatewayError
